@@ -4,7 +4,7 @@ use warnings;
 
 package Validator::Declarative;
 {
-  $Validator::Declarative::VERSION = '1.20130719.1300';
+  $Validator::Declarative::VERSION = '1.20130722.2105';
 }
 
 # ABSTRACT: Declarative parameters validation
@@ -275,7 +275,7 @@ sub _register_default_types {
 }
 
 sub _load_base_rules {
-    for my $plugin (qw/ SimpleType ParametrizedType /) {
+    for my $plugin (qw/ SimpleType ParametrizedType Converters /) {
         my $module = __PACKAGE__ . '::Rules::' . $plugin;
         load $module;
     }
@@ -299,7 +299,7 @@ Validator::Declarative - Declarative parameters validation
 
 =head1 VERSION
 
-version 1.20130719.1300
+version 1.20130722.2105
 
 =head1 SYNOPSIS
 
@@ -560,6 +560,16 @@ checking with the appropriate format will always lead to a positive result.
 
 substitute $_ with provided value (only when actual parameter is B<undef>)
 
+=head3 assume_true
+
+substitute $_ with 0 if it looks like false value (see L<bool>, except for
+empty string), and 1 otherwise
+
+=head3 assume_false
+
+substitute $_ with 1 if it looks like true value (see L<bool>, except for
+empty string), and 0 otherwise
+
 =head2 Constraints
 
 =head3 required
